import unittest
from os import getenv
from os.path import isfile, dirname, join

from dotenv import load_dotenv
from faker import Faker
from requests import codes

from SoundingCenter import Api


class TestApi(unittest.TestCase):
    def setUp(self):
        env_file = join(dirname(__file__), '../../.env')

        if not isfile(env_file):
            print('script can not start because .env file is missing')
            exit(1)

        load_dotenv(env_file)

        self.api = Api(getenv('SC_API_URL'), getenv('SC_ADMIN_USERNAME'), getenv('SC_ADMIN_PASSWORD'), True)
        self.fake = Faker()

    def test_user(self):
        response = self.api.user()
        self.assertEqual(response.status_code, codes.ok)

    def test_create_user(self):
        response = self.api.create_user(self.fake.email(), self.fake.password(), 'user', self.fake.name())
        self.assertEqual(response.status_code, codes.created)

    def test_create_station(self):
        response = self.api.create_station(
            self.fake.name(), 'operated_fixed', self.fake.random_int(10000, 99999),
            float(self.fake.latitude()), float(self.fake.longitude()), self.fake.random_int(min=0, max=8848)
        )
        self.assertEqual(response.status_code, codes.created)

    def test_attach_station_to_user(self):
        user = self.api.create_user(self.fake.email(), self.fake.password(), 'user', self.fake.name()).json()
        station = self.api.create_station(
            self.fake.name(), 'operated_fixed', self.fake.random_int(10000, 99999),
            float(self.fake.latitude()), float(self.fake.longitude()), self.fake.random_int(min=0, max=8848)
        ).json()
        response = self.api.attach_station_to_user(user['data']['id'], station['data']['id'])
        self.assertEqual(response.status_code, 200)


if __name__ == '__main__':
    unittest.main()



from requests import Response, get, post


class Api:
    def __init__(self, base_url: str, username: str, password: str, logging: bool = False):
        self.base_url = base_url
        self.auth = (username, password)
        self.logging = logging

    def log(self, response: Response):
        if self.logging and not response.ok:
            print(response.status_code)
            print(response.content)

    def get(self, path: str):
        request = get(
            url=f'{self.base_url}/{path}',
            headers={
                'Accept': 'application/json',
            },
            auth=self.auth,
        )

        self.log(request)
        return request

    def post(self, path: str, json):
        request = post(
            url=f'{self.base_url}/{path}',
            headers={
                'Accept': 'application/json',
                'Content-Type': 'application/json'
            },
            auth=self.auth,
            json=json,
        )

        self.log(request)
        return request

    def user(self):
        return self.get('user/self')

    def create_user(self, email: str, password: str, role: str, name: str):
        return self.post('user', {
            'email': email,
            'password': password,
            'role': role,
            'name': name,
        })

    def create_station(
            self,
            name: str,
            station_type: str,
            wmo_id: int,
            latitude: float,
            longitude: float,
            altitude: float
    ):
        return self.post('station', {
            'name': name,
            'type': station_type,
            'wmo_id': wmo_id,
            'latitude': latitude,
            'longitude': longitude,
            'altitude': altitude,
        })

    def attach_station_to_user(self, user_id: int, station_id: int):
        return self.post(f'user/{user_id}/attachStation/{station_id}', {})
